"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.packFiles = void 0;
const vscode = require("vscode");
const path = require("path");
const fs = require("fs");
const fileParser_1 = require("../utils/fileParser");
const jsonBuilder_1 = require("../utils/jsonBuilder");
const configParser_1 = require("../utils/configParser");
async function readLocalConfig(directoryPath) {
    const configPath = path.join(directoryPath, 'CONFIG.json');
    console.log('Trying to read config from:', configPath);
    if (fs.existsSync(configPath)) {
        try {
            const configContent = fs.readFileSync(configPath, 'utf8');
            const config = JSON.parse(configContent);
            console.log('Successfully read config:', config);
            return config;
        }
        catch (error) {
            console.error(`Error reading CONFIG.json at ${directoryPath}:`, error);
            vscode.window.showWarningMessage(`读取配置文件失败: ${configPath}`);
            return null;
        }
    }
    console.log('No CONFIG.json found at:', directoryPath);
    return null;
}
async function processFile(file, currentIndex, currentDirPath) {
    try {
        const localConfig = await readLocalConfig(currentDirPath);
        console.log('Local config for', file, ':', localConfig);
        const defaultConfig = (0, configParser_1.getDefaultConfig)(currentIndex);
        const fileContent = await (0, fileParser_1.parseFile)(file, currentIndex);
        if (!fileContent) {
            return null;
        }
        const finalConfig = (0, configParser_1.mergeConfigurations)(defaultConfig, localConfig, fileContent.config);
        const fileNameWithoutExt = path.basename(file, path.extname(file));
        finalConfig.comment = fileNameWithoutExt;
        finalConfig.content = fileContent.content;
        console.log('Final processed config:', finalConfig);
        return [currentIndex.toString(), finalConfig];
    }
    catch (error) {
        console.error('Error processing file:', file, error);
        return null;
    }
}
async function packFiles() {
    try {
        const editor = vscode.window.activeTextEditor;
        if (!editor) {
            throw new Error('请打开一个文件进行打包');
        }
        const currentFilePath = editor.document.uri.fsPath;
        const currentDir = path.dirname(currentFilePath);
        await vscode.window.withProgress({
            location: vscode.ProgressLocation.Notification,
            title: "正在打包文件...",
            cancellable: false
        }, async (progress) => {
            const files = await getAllFiles(currentDir);
            const entries = {};
            let currentIndex = 0;
            const processedFiles = new Set();
            for (const file of files) {
                progress.report({ increment: 100 / files.length });
                const fileName = path.basename(file);
                if (fileName === 'output.json' || fileName === 'CONFIG.json' || fileName.startsWith('!')) {
                    continue;
                }
                const stat = fs.statSync(file);
                const fileNameWithoutExt = path.basename(file, path.extname(file));
                const currentDirPath = path.dirname(file);
                if (stat.isDirectory()) {
                    if (fileName.startsWith('!')) {
                        continue;
                    }
                    // 处理文件夹开始标记
                    entries[currentIndex.toString()] = (0, configParser_1.getFolderConfig)(currentIndex, fileNameWithoutExt);
                    currentIndex++;
                    // 读取文件夹的配置
                    const dirLocalConfig = await readLocalConfig(file);
                    // 处理文件夹内的文件
                    for (const dirFile of files) {
                        if (dirFile.startsWith(file + path.sep) &&
                            path.dirname(dirFile) === file &&
                            !processedFiles.has(dirFile) &&
                            !fs.statSync(dirFile).isDirectory()) {
                            const result = await processFile(dirFile, currentIndex, file);
                            if (result) {
                                const [index, config] = result;
                                entries[index] = config;
                                currentIndex++;
                                processedFiles.add(dirFile);
                            }
                        }
                    }
                    // 处理文件夹结束标记
                    entries[currentIndex.toString()] = (0, configParser_1.getFolderConfig)(currentIndex, fileNameWithoutExt, true);
                    currentIndex++;
                }
                else if (!processedFiles.has(file)) {
                    const result = await processFile(file, currentIndex, currentDirPath);
                    if (result) {
                        const [index, config] = result;
                        entries[index] = config;
                        currentIndex++;
                        processedFiles.add(file);
                    }
                }
            }
            const json = (0, jsonBuilder_1.buildJson)(entries);
            const savePath = path.join(currentDir, 'output.json');
            fs.writeFileSync(savePath, JSON.stringify(json, null, 2), 'utf8');
            vscode.window.showInformationMessage(`打包完成，已保存至：${savePath}`);
        });
    }
    catch (error) {
        handleError(error);
    }
}
exports.packFiles = packFiles;
function handleError(error) {
    const errorMessage = error instanceof Error ? error.message : '未知错误';
    vscode.window.showErrorMessage(`打包失败: ${errorMessage}`);
}
async function getAllFiles(dir) {
    const files = [];
    const entries = fs.readdirSync(dir, { withFileTypes: true });
    for (const entry of entries) {
        const fullPath = path.join(dir, entry.name);
        if (entry.isDirectory()) {
            files.push(fullPath);
            files.push(...await getAllFiles(fullPath));
        }
        else {
            files.push(fullPath);
        }
    }
    return files.sort((a, b) => {
        const aIsDir = fs.statSync(a).isDirectory();
        const bIsDir = fs.statSync(b).isDirectory();
        if (aIsDir && !bIsDir)
            return -1;
        if (!aIsDir && bIsDir)
            return 1;
        return a.localeCompare(b);
    });
}
//# sourceMappingURL=pack.js.map