"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.packFiles = void 0;
const vscode = require("vscode");
const path = require("path");
const fs = require("fs");
const fileParser_1 = require("./utils/fileParser");
const jsonBuilder_1 = require("./utils/jsonBuilder");
const configParser_1 = require("./utils/configParser");
const fileSystem_1 = require("./utils/fileSystem");
const configProcessor_1 = require("./utils/configProcessor");
async function processFile(file, index, localConfig) {
    try {
        const defaultConfig = (0, configParser_1.getDefaultConfig)(index);
        const fileContent = await (0, fileParser_1.parseFile)(file.path, index);
        if (!fileContent)
            return null;
        const finalConfig = (0, configProcessor_1.mergeConfigs)(defaultConfig, localConfig, fileContent.config);
        return [
            index.toString(),
            {
                // pack.ts (继续)
                ...finalConfig,
                content: fileContent.content,
                comment: file.nameWithoutExt
            }
        ];
    }
    catch (error) {
        console.error(`Error processing file ${file.path}:`, error);
        return null;
    }
}
async function packFiles() {
    try {
        const editor = vscode.window.activeTextEditor;
        if (!editor) {
            throw new Error('请打开一个文件进行打包');
        }
        const currentFilePath = editor.document.uri.fsPath;
        const currentDir = path.dirname(currentFilePath);
        await vscode.window.withProgress({
            location: vscode.ProgressLocation.Notification,
            title: "正在打包文件...",
            cancellable: false
        }, async (progress) => {
            const files = await (0, fileSystem_1.getAllFiles)(currentDir);
            const entries = {};
            let currentIndex = 0;
            const processedFiles = new Set();
            for (const file of files) {
                progress.report({ increment: 100 / files.length });
                if (file.isDirectory) {
                    if (file.name.startsWith('!'))
                        continue;
                    // 处理目录开始标记
                    entries[currentIndex.toString()] = {
                        ...(0, configParser_1.getFolderConfig)(currentIndex, file.nameWithoutExt),
                        disable: true
                    };
                    currentIndex++;
                    // 处理目录内文件
                    const dirConfig = await (0, configProcessor_1.readLocalConfig)(file.path);
                    const dirFiles = files.filter(f => f.dirPath === file.path &&
                        (0, fileSystem_1.isValidFile)(f) &&
                        !processedFiles.has(f.path));
                    for (const dirFile of dirFiles) {
                        const result = await processFile(dirFile, currentIndex, dirConfig);
                        if (result) {
                            const [key, value] = result;
                            entries[key] = value;
                            currentIndex++;
                            processedFiles.add(dirFile.path);
                        }
                    }
                    // 处理目录结束标记
                    entries[currentIndex.toString()] = {
                        ...(0, configParser_1.getFolderConfig)(currentIndex, file.nameWithoutExt, true),
                        disable: true
                    };
                    currentIndex++;
                }
                else if ((0, fileSystem_1.isValidFile)(file) && !processedFiles.has(file.path)) {
                    const dirConfig = await (0, configProcessor_1.readLocalConfig)(file.dirPath);
                    const result = await processFile(file, currentIndex, dirConfig);
                    if (result) {
                        const [key, value] = result;
                        entries[key] = value;
                        currentIndex++;
                        processedFiles.add(file.path);
                    }
                }
            }
            const json = (0, jsonBuilder_1.buildJson)(entries);
            const savePath = path.join(currentDir, 'output.json');
            fs.writeFileSync(savePath, JSON.stringify(json, null, 2), 'utf8');
            vscode.window.showInformationMessage(`打包完成，已保存至：${savePath}`);
        });
    }
    catch (error) {
        const errorMessage = error instanceof Error ? error.message : '未知错误';
        vscode.window.showErrorMessage(`打包失败: ${errorMessage}`);
    }
}
exports.packFiles = packFiles;
//# sourceMappingURL=pack.js.map