"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseFile = void 0;
const fs = require("fs");
const yaml = require("js-yaml");
async function parseFile(filePath, uid) {
    try {
        const content = fs.readFileSync(filePath, 'utf-8');
        const extension = filePath.split('.').pop()?.toLowerCase();
        switch (extension) {
            case 'md':
                return parseMarkdown(content);
            case 'yml':
            case 'yaml':
                return parseYaml(content);
            case 'json':
                return parseJson(content);
            default:
                return createParsedFile(content, {});
        }
    }
    catch (error) {
        console.error(`Error parsing file ${filePath}:`, error);
        return null;
    }
}
exports.parseFile = parseFile;
function createParsedFile(content, config) {
    return {
        content: content.trim(),
        config: config
    };
}
function normalizeConfig(rawConfig) {
    const config = {};
    // Array fields
    if (rawConfig.key !== undefined) {
        config.key = Array.isArray(rawConfig.key) ? rawConfig.key : [rawConfig.key];
    }
    if (rawConfig.keysecondary !== undefined) {
        config.keysecondary = Array.isArray(rawConfig.keysecondary) ? rawConfig.keysecondary : [rawConfig.keysecondary];
    }
    // Boolean fields
    const booleanFields = [
        'constant', 'vectorized', 'selective', 'addMemo',
        'disable', 'excludeRecursion', 'preventRecursion',
        'delayUntilRecursion', 'useProbability', 'groupOverride'
    ];
    booleanFields.forEach(field => {
        if (rawConfig[field] !== undefined) {
            config[field] = Boolean(rawConfig[field]);
        }
    });
    // Number fields
    const numberFields = [
        'order', 'probability', 'depth', 'groupWeight',
        'sticky', 'cooldown', 'delay', 'displayIndex', 'selectiveLogic',
        'position'
    ];
    numberFields.forEach(field => {
        if (rawConfig[field] !== undefined) {
            config[field] = Number(rawConfig[field]);
        }
    });
    // String fields
    const stringFields = [
        'comment', 'group', 'automationId'
    ];
    stringFields.forEach(field => {
        if (rawConfig[field] !== undefined) {
            config[field] = String(rawConfig[field]);
        }
    });
    // Nullable fields
    const nullableFields = [
        'scanDepth', 'caseSensitive', 'matchWholeWords',
        'useGroupScoring', 'role'
    ];
    nullableFields.forEach(field => {
        if (rawConfig[field] !== undefined) {
            config[field] = rawConfig[field];
        }
    });
    return config;
}
function parseMarkdown(content) {
    const frontMatterRegex = /^---([\s\S]*?)---\s*([\s\S]*)$/;
    const match = content.match(frontMatterRegex);
    if (match) {
        try {
            const [_, frontMatterStr, contentStr] = match;
            const rawConfig = yaml.load(frontMatterStr.trim());
            const normalizedConfig = normalizeConfig(rawConfig || {});
            return {
                content: contentStr.trim(),
                config: normalizedConfig
            };
        }
        catch (error) {
            console.error('Error parsing front matter:', error);
            return createParsedFile(content, {});
        }
    }
    return createParsedFile(content, {});
}
function parseYaml(content) {
    try {
        const data = yaml.load(content);
        let config = {};
        let parsedContent = '';
        if (data && typeof data === 'object') {
            if (data.CONFIG) {
                config = normalizeConfig(data.CONFIG);
                delete data.CONFIG;
            }
            parsedContent = yaml.dump(data);
        }
        return createParsedFile(parsedContent, config);
    }
    catch (error) {
        return createParsedFile(content, {});
    }
}
function parseJson(content) {
    try {
        const data = JSON.parse(content);
        let config = {};
        let parsedContent = '';
        if (data && typeof data === 'object') {
            if (data.CONFIG) {
                config = normalizeConfig(data.CONFIG);
                delete data.CONFIG;
            }
            parsedContent = JSON.stringify(data, null, 2);
        }
        return createParsedFile(parsedContent, config);
    }
    catch (error) {
        return createParsedFile(content, {});
    }
}
//# sourceMappingURL=fileParser.js.map